@@ -6,7 +6,7 @@ use warnings;
 
 use Data::Dumper;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 NAME
 
@@ -14,7 +14,7 @@ Protocol::ACME - Interface to the Let's Encrypt ACME API
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =head1 SYNOPSIS
 
@@ -290,6 +290,7 @@ use warnings;
 
 use Protocol::ACME::Utils;
 
+use Crypt::Format;
 use Crypt::RSA::Parse ();
 
 use MIME::Base64 qw( encode_base64url decode_base64url decode_base64 encode_base64 );
@@ -428,9 +429,8 @@ sub load_key
     if ( ! Protocol::ACME::Utils::looks_like_pem($keystring) )
     {
 
-      print "HERE\n";
       #TODO: This should detect/handle PKCS8-formatted private keys as well.
-      $keystring = Protocol::ACME::Utils::der2pem( $keystring, "RSA PRIVATE KEY" );
+      $keystring = Crypt::Format::der2pem( $keystring, "RSA PRIVATE KEY" );
       print $keystring;
     }
 
@@ -548,7 +548,7 @@ sub recovery_key
 
   my $url = "https://acme-staging.api.letsencrypt.org/acme/reg/101834";
 
-  my $der = Protocol::ACME::Utils::pem2der( $pem );
+  my $der = Crypt::Format::pem2der( $pem );
 
   my $pub = Crypt::PK::ECC->new( \$der );
 
@@ -984,9 +984,14 @@ L<http://search.cpan.org/dist/Protocol-ACME/>
 =back
 
 
+=head1 CONTRIBUTORS
+
+Felipe Gasper, C<< <felipe at felipegasper.com> >>
+
 =head1 ACKNOWLEDGEMENTS
 
 
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2015 Stephen Ludin.
